// file: $USFS/class/image_analysis/v1.0/imaga_hist_05.cc
//

// isip include files
//
#include "image_analysis.h"

#include "image_analysis_constants.h"
#include <integral_constants.h>

// method: hist_assign_cc
//
// arguments:
//  uint_1* b_red: (input) red buffer
//  uint_1* b_green: (input) green buffer
//  uint_1* b_blue: (input) blue buffer
//  int_4 npixels_a: (input) number of pixels
//
// return: a logical_1 value indicating the status
//
// this method assigns data points to bins in the histogram.
// note that the histogram is assumed to extend from:
//
//   [min_val - bin_width/2] to [max_val + bin_width/2]
//
// points outside this range are assigned to the end bins.
//
logical_1 Image_analysis::hist_assign_cc(uint_1* b_red, uint_1* b_green,
					 uint_1* b_blue, int_4 npixels_a) {
  
  // compute the quantization constants
  //
  float_8 bin_width = (hist_max_d - hist_min_d) / (float_8)hist_nbins_d;
  float_8 min_val = hist_min_d - 0.5 * bin_width;
  float_8 max_val = hist_max_d + 0.5 * bin_width;
  float_8 range = max_val - min_val;
  float_8 scale = (float_8)hist_nbins_d / range;
  
  // loop over all the data
  //
  int_4 index;

  for (int_4 i=0; i<npixels_a; i++) {
      
    // process the red pixel
    //
    index = hist_compute_index_cc((float_8)b_red[i],
				  min_val, max_val, scale);
    hist_t_rpdf_d[index] += (float_8)1.0;
      
    // process the green pixel
    //
    index = hist_compute_index_cc((float_8)b_green[i],
				  min_val, max_val, scale);
    hist_t_gpdf_d[index] += (float_8)1.0;
      
    // process the blue pixel
    //
    index = hist_compute_index_cc((float_8)b_blue[i],
				  min_val, max_val, scale);
    hist_t_bpdf_d[index] += (float_8)1.0;

    // increment the pixel counter
    //
    hist_t_npxls_d++;
  }
  
  // exit gracefully
  //
  return ISIP_TRUE;
}
