// file: $USFS/class/image_analysis/v1.0/imaga_init_0.cc
//

// isip include files
//
#include "image_analysis.h"

#include "image_analysis_constants.h"
#include <integral_constants.h>

// method: init_cc
//
// arguments: none
//
// return: a logical_1 value indicating status
//
// this method checks for the mode for train, initializes the data and calls
// hist_init_cc 
//
logical_1 Image_analysis::init_cc() {
  
  // check for the mode
  //
  if (mode_d == IMAGA_MODE_TRAIN && algorithm_d == IMAGA_ALG_HISTOGRAM) {
    
    // initialize the private data
    //
    hist_min_d = IMAGA_HIST_MIN;
    hist_max_d = IMAGA_HIST_MAX;
    hist_nbins_d = IMAGA_HIST_NBINS;
    hist_redp_d = IMAGA_HIST_RPTR;
    hist_grnp_d = IMAGA_HIST_GPTR;
    hist_blup_d = IMAGA_HIST_BPTR;
    
    if (hist_init_cc() == ISIP_FALSE) {
      error_handler_cc((char_1*)"init_cc",
		       (char_1*)"error while initializing the histogram");
      return ISIP_FALSE;
    }
    
    float_8 range = (hist_max_d - hist_min_d) / (float_8)(hist_nbins_d - 1);
    
    // initializing the center values
    //
    hist_t_rcval_d[0] = hist_min_d;
    hist_t_gcval_d[0] = hist_min_d;
    hist_t_bcval_d[0] = hist_min_d;
    
    for (int_4 i=1; i < hist_nbins_d; i++) {
      hist_t_rcval_d[i] = hist_t_rcval_d[i-1] + range;
      hist_t_gcval_d[i] = hist_t_gcval_d[i-1] + range;
      hist_t_bcval_d[i] = hist_t_bcval_d[i-1] + range;
    }
  }
  
  if ((mode_d == IMAGA_MODE_TRAIN) && (algorithm_d == IMAGA_ALG_EDGEDET)) {
    
    // initialize the private data
    //
    edge_nbins_d = IMAGA_EDGE_NBINS;
    edge_rfact_d = IMAGA_EDGE_FACTOR;
    edge_msize_d = IMAGA_EDGE_MSIZE;
    edge_xmean_d = IMAGA_EDGE_XMEAN;
    edge_ymean_d = IMAGA_EDGE_YMEAN;
    edge_lmin_d = IMAGA_EDGE_LMIN;
    edge_lmax_d = IMAGA_EDGE_LMAX;
    edge_lwgt_d = IMAGA_EDGE_LWGT;
    edge_sigma_d = IMAGA_EDGE_SIGMA;
    
    if (edge_init_cc() == ISIP_FALSE) {
      error_handler_cc((char_1*)"init_cc",
		       (char_1*)"error while initializing the edge detection");
    }
    
    float_4 range = (edge_lmax_d - edge_lmin_d) / (int_4)(edge_nbins_d - 1);
    
    // initializing the center values
    //
    edge_t_lcval_d[0] = 0.0;
    
    for (int_4 i=1; i < edge_nbins_d; i++) {
      edge_t_lcval_d[i] = edge_t_lcval_d[i-1] + range;
    }
  }
  
  // exit gracefully
  //
  return ISIP_TRUE;
}

  
