// file: $USFS/class/image_analysis/v1.0/imaga_load_0.cc
//

// isip include files
//
#include "image_analysis.h"

#include "image_analysis_constants.h"
#include <integral_constants.h>

// method: load_cc
//
// arguments:
//  char_1* param_file: (input) the parameter file to be read
//
// return: a logical_1 value indicating status
//
// this method opens the parameter file and reads the mode, algorithm,
// and other appropriate information.
//
logical_1 Image_analysis::load_cc(char_1* param_file_a) {

  // open the parameter file
  //
  FILE* fp = open_cc(param_file_a, ISIP_READ_ONLY);
  if (fp == (FILE*)NULL) {
    error_handler_cc((char_1*)"load_cc",
		     (char_1*)"error loading parameter file");
    return ISIP_FALSE;
  }
  
  // read the version used (first line in the file)
  //
  char_1 buf[ISIP_MAX_STRING_LENGTH];

  if (fscanf(fp, "%s", (char*)buf) == (int)0) {
    error_handler_cc((char_1*)"load_cc", (char_1*)"version not found");
    return ISIP_FALSE;
  }
  
  // check the version
  //
  if (strcmp ((char*)buf, (char*)IMAGA_VERSION) != (int)0) {
    error_handler_cc((char_1*)"load_cc", (char_1*)"incorrect version");
    return ISIP_FALSE;
  }
  param_version_d = new char_1[strlen((char*)buf) + (int_4)1];
  strcpy((char*)param_version_d, (char*)buf);
  
  // get the mode
  //
  if (get_mode_cc(fp) == ISIP_FALSE) {
    error_handler_cc((char_1*)"load_cc", (char_1*)"invalid mode");
    return ISIP_FALSE;
  }
  
  // get the algorithm
  //
  if (get_algorithm_cc(fp) == ISIP_FALSE) {
    error_handler_cc((char_1*)"load_cc", (char_1*)"invalid algorithm");
    return ISIP_FALSE;
  }
  
  // get the model filename (must be specified in all cases)
  //
  if (get_modelfile_cc(fp) == ISIP_FALSE) {
    error_handler_cc((char_1*)"load_cc", (char_1*)"invalid model filename");
    return ISIP_FALSE;
  }
  
  // load the model only if it is test or update
  //
  if ((mode_d == IMAGA_MODE_TEST) || (mode_d == IMAGA_MODE_UPDATE)) {
    if (load_model_cc() == ISIP_FALSE) {
      error_handler_cc((char_1*)"load_cc",
		       (char_1*)"error loading the reference model");
      return ISIP_FALSE;
    }
  }

  // else: unknown mode
  //
  //else {
  //error_handler_cc((char_1*)"load_cc", (char_1*)"unknown mode");
  //return ISIP_FALSE;
  //}
  
  // close the file
  //
  if (close_cc(fp) == ISIP_FALSE) {
    error_handler_cc((char_1*)"load_cc", (char_1*)"error closing the file");
    return ISIP_FALSE;
  }
  
  // provide some debugging information
  //
  if (debug_level_d > ISIP_DEBUG_BRIEF) {
    fprintf(stdout,
	    "<%s> version: %s algorithm: %ld\n",
	    "Image_analysis::load_cc", param_version_d, algorithm_d);
    fprintf(stdout, "mode = %ld model_filename: %s\n",
	    mode_d, model_fname_d);
  }
  
  // dump the model
  //
  if (debug_level_d > ISIP_DEBUG_DETAILED) {
    display_model_cc(stdout);
  }

  // exit gracefully
  //
  return ISIP_TRUE;
}
