// file: $USFS/class/image_analysis/v1.0/image_analysis_constants.h
//
// this file defines global paths, filenames and constants of the
// image analysis class

// make sure the definitions are made only once
//
#ifndef __ISIP_IMAGE_ANALYSIS_CONSTANTS
#define __ISIP IMAGE_ANALYSIS_CONSTANTS

// isip include files
//
#ifndef __ISIP_INTEGRAL
#include <integral.h>
#endif

// define the class name
//
#define IMAGE_ANALYSIS_CLASS_NAME (char_1*)"Image_analysis"

// define latest version of the software
//
#define IMAGA_VERSION (char_1*)"ANALYZE_IMAGE_V1.0"
#define IMAGA_MODEL_VERSION (char_1*)"ANALYZE_IMAGE_V1.0"

// define available modes
//
#define IMAGA_MODE (char_1*)"mode"
#define IMAGA_MODE_NONE (int_4)-1

#define IMAGA_MODE_TEST (int_4)0
#define IMAGA_MODE_TEST_NAME (char_1*)"test"

#define IMAGA_MODE_TRAIN (int_4)1
#define IMAGA_MODE_TRAIN_NAME (char_1*)"train"

#define IMAGA_MODE_UPDATE (int_4)2
#define IMAGA_MODE_UPDATE_NAME (char_1*)"update"

// define available algorithms
//
#define IMAGA_ALG (char_1*)"algorithm"
#define IMAGA_ALG_NONE (int_4)-1

#define IMAGA_ALG_HISTOGRAM (int_4)0
#define IMAGA_ALG_HISTOGRAM_NAME (char_1*)"histogram"

#define IMAGA_ALG_EDGEDET (int_4)1
#define IMAGA_ALG_EDGEDET_NAME (char_1*)"edge_detection"

// define parameter keywords
//
#define IMAGA_MODEL_FILE (char_1*)"model_file"

//-----------------------------------------------------------------------------
//
// define histogram-specific constants
//
//-----------------------------------------------------------------------------
//
#define IMAGA_HIST_MODEL_LINES (int_4)8
#define IMAGA_HIST_COMMENT ISIP_POUND
#define IMAGA_HIST_COMMENT_FORMAT (char_1*)"%c %s\n%c\n"
#define IMAGA_HIST_ALG_COMMENT (char_1*)"define the type of the model file"
#define IMAGA_HIST_PARAM_COMMENT (char_1*)"define the parameters of the histogram"
#define IMAGA_HIST_COLOR_COMMENT (char_1*)"define the red, green and blue indices"
#define IMAGA_HIST_DATA_COMMENT (char_1*)"define the amount of data used to generate the histograms"
#define IMAGA_HIST_VALUES_COMMENT (char_1*)"specify the histogram values"
#define IMAGA_HIST_CWTS_COMMENT (char_1*)"specify the color weights"
#define IMAGA_HIST_SCAL_COMMENT (char_1*)"specify the scaling function"

// define the constants to be used for the training mode
//
#define IMAGA_HIST_MIN (float_8)0
#define IMAGA_HIST_MAX (float_8)255
#define IMAGA_HIST_NBINS (int_4)100
#define IMAGA_HIST_RPTR (int_4)0
#define IMAGA_HIST_GPTR (int_4)1
#define IMAGA_HIST_BPTR (int_4)2
#define IMAGA_HIST_WRED (float_4)0.33
#define IMAGA_HIST_WGRN (float_4)0.33
#define IMAGA_HIST_WBLU (float_4)0.33
#define IMAGA_HIST_ASCL (int_4)-100
#define IMAGA_HIST_BSCL (int_4)100

// define formats used to parse parameter file data
//
#define IMAGA_FORMAT_0 (char_1*)"%s%*s%s"
#define IMAGA_FORMAT_1 (char_1*)"%ld%ld%e"

// declare the block size
//
#define IMAGA_DEFAULT_BSIZE (int_4)256

// define parameters related to parsing the model file
//
#define IMAGA_HIST_NPARAMS (int_4)14

//-----------------------------------------------------------------------------
//
// define edge detection-specific constants
//
//-----------------------------------------------------------------------------
//
#define IMAGA_EDGE_WOFF (int)0
#define IMAGA_EDGE_HOFF (int)0

// define the constant for PI
//
#define PI 3.14

// define the constants to be used for the training mode
//
#define IMAGA_EDGE_MODEL_LINES (int_4)7
#define IMAGA_EDGE_FACTOR (float_4)0.7
#define IMAGA_EDGE_XMEAN (float_4)0.0
#define IMAGA_EDGE_YMEAN (float_4)0.0
#define IMAGA_EDGE_SIGMA (float_4)9.0
#define IMAGA_EDGE_MSIZE (int_4)3

// define the constants to be used for computing the length of lines
//
#define IMAGA_EDGE_COLMAX (int_4)255
#define IMAGA_EDGE_COLMIN (int_4)0
#define IMAGA_EDGE_HDEV (int_4)2
#define IMAGA_EDGE_VDEV (int_4)5
#define IMAGA_EDGE_SLIM (int_4)25
#define IMAGA_EDGE_LLIM (int_4)50
#define IMAGA_EDGE_PINCR (int_4)4
#define IMAGA_EDGE_PIXEL (int_4)15
#define IMAGA_EDGE_MAX (float_4)0.0
#define IMAGA_EDGE_MIN (float_4)1000.0
#define IMAGA_EDGE_MNUM (char_1*)"P5"
#define IMAGA_EDGE_RCNST (float_4)0.299
#define IMAGA_EDGE_GCNST (float_4)0.587
#define IMAGA_EDGE_BCNST (float_4)0.114
#define IMAGA_EDGE_LMIN (float_4)0.0
#define IMAGA_EDGE_LMAX (float_4)1024.0

// define the constants to be written into the model file
//
#define IMAGA_EDGE_NPARAMS (int_4)13
#define IMAGA_EDGE_NBINS (int_4)100
#define IMAGA_EDGE_ASCL (float_4)-100
#define IMAGA_EDGE_BSCL (float_4)100
#define IMAGA_EDGE_LWGT (float_4)0.33
#define IMAGA_EDGE_SWGT (float_4)0.33

//-----------------------------------------------------------------------------
//
// define edge detection-specific constants
//
//-----------------------------------------------------------------------------
//
#define IMAGA_EDGE_PARAM_COMMENT (char_1*)"define the parameters of the edgedetection"
#define IMAGA_EDGE_DATA_COMMENT (char_1*)"define the amount of data used to generate the edge detection"
#define IMAGA_EDGE_LWGTS_COMMENT (char_1*)"specify the line weights"
#define IMAGA_EDGE_VALUES_COMMENT (char_1*)"specify the line numbers"

// end of file
//
#endif
   


















